#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NONE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NONE_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/none.hpp>

#endif
